Reference
=========

APIs
----

.. module:: cosmic.api

.. autoclass:: cosmic.api.API
   :members:

.. autoclass:: cosmic.models.Model
   :members:

Exceptions
----------

.. automodule:: cosmic.exceptions

.. autoclass:: cosmic.exceptions.ModelNotFound
   :members:

.. autoclass:: cosmic.exceptions.SpecError
   :members:

Tools and Helpers
-----------------

.. automodule:: cosmic.tools
   :members:
   :undoc-members:
